On Fri, Sep 25, 2015 at 12:22 AM, Eric Covener <[email protected]> wrote:
>
> two logs (http/https) sorted to top of autoindex here:
> http://people.apache.org/~covener/
>
> Narrow logio issue working good now, because our first filter
> invocation is not delayed like the "addbytes" callback was.
Looks like mod_ssl should also forward EOR buckets.
Does this work:
Index: modules/ssl/ssl_engine_io.c
===================================================================
--- modules/ssl/ssl_engine_io.c (revision 1705160)
+++ modules/ssl/ssl_engine_io.c (working copy)
@@ -1707,12 +1707,12 @@ static apr_status_t ssl_io_filter_output(ap_filter
/* If it is a flush or EOS, we need to pass this down.
* These types do not require translation by OpenSSL.
*/
- if (APR_BUCKET_IS_EOS(bucket)) {
+ if (APR_BUCKET_IS_EOS(bucket) || AP_BUCKET_IS_EOR(bucket)) {
/*
* By definition, nothing can come after EOS.
* which also means we can pass the rest of this brigade
* without creating a new one since it only contains the
- * EOS bucket.
+ * EOS/EOR bucket.
*/
if ((status = ap_pass_brigade(f->next, bb)) != APR_SUCCESS) {
?
@@ -1707,12 +1707,12 @@ static apr_status_t ssl_io_filter_output(ap_filter
/*
- * By definition, nothing can come after EOS.
+ * By definition, nothing can come after EOS/EOR.
* which also means we can pass the rest of this brigade
* without creating a new one since it only contains the